@@ -1,3 +1,5 @@
+use std::collections::HashMap;
+
 use crate::types::Field;
 use crate::validate::Validator;
 use proc_macro2::TokenStream;
@@ -6,9 +8,11 @@ use quote::quote;
 pub fn extract_generic_custom_validator(
     field: &impl Field,
     syn::MetaList { path, nested, .. }: &syn::MetaList,
+    rename_map: &HashMap<String, String>,
 ) -> Result<Validator, crate::Errors> {
     let field_name = field.name();
     let field_ident = field.ident();
+    let rename = rename_map.get(field_name).unwrap_or(field_name);
 
     let custom_fn_name = match nested.len() {
         0 => Err(crate::Error::validate_custom_need_item(path)),
@@ -20,7 +24,7 @@ pub fn extract_generic_custom_validator(
     Ok(Validator::Normal(quote!(
         if let Err(__error) = #custom_fn_name(#field_ident) {
             __errors
-                .entry(#field_name)
+                .entry(#rename)
                 .or_default()
                 .push(__error);
         };
